%% Setup model paramters
%% Alexey Ryabov, 10.03.2015
%% please contact alexey.ryabov@uni-oldenburg.de if you need any help to use this code

function [Int, dx, L, CellNumb, fl, dt, tmin, tmax, t, tsteps, TimeSteps, ...
    ReshuffleTime, res, D, S, R, ResDyn, d, r, m, R_eq, c, N,DispRes] = ...
Model_Params (Params, ReshuffleStep)


Diff = Params.Diff;
tmax = Params.tmax;
sp   = Params.sp;
specID = Params.specID;

%% Model parameters
Int = 100; % iteration interval which is plotted later
dx = 1; % space resolution
L = 20; % number of bins in 2D
CellNumb = L^2;
fl = 0; % flux rate at the bounadries (in this case: no flux)

%DataFileName = [mfilename('fullpath'), '.dat'];

%Diff =0.1; %Diffusivity of species


if Diff == 0
    dt = 0.1;
else
    dt = min(0.1, 0.5 * (dx^2/(4*Diff))); %time step should satisfy the stability criterion
end
Int = Int/dt;
tmin = 0; % starting time
t = tmin:dt:tmax; % time vector
tsteps = length(t);
TimeSteps = []; %This time will be saved
%ReshuffleStep = 100; %Time steps between reshuffling
ReshuffleTime = ReshuffleStep; %Time of reshuffle


%rand('seed',1); % optional repetition of the same random values

%% Resources
res = 2; %Number of resources
D = 0.25 * ones(L, L, res); %  supply rate of the resources (in 1/d) in each point
DispRes = 0; %dispersal rate of resources

%generate resource supply points for te required range 
S(:, :, 1) = repmat(linspace(Params.ResLow, Params.ResHigh, L), L, 1); % values of S1 and S2 are randomly generated
S(:, :, 2) = repmat(linspace(Params.ResHigh, Params.ResLow, L), L, 1); % values of S1 and S2 are randomly generated


switch Params.ResDistr
    case 'l'
        %use this for scenario: Random Locations
        S = resourceshuffle(S,L,res);
    case 's'
        %use this for scenario: Random Supplies
        S = randresshuffle(S,L,res);
    case 'g'
        %use this for scenario: Random Supplies
    otherwise 
        error('The resource type is undefined');
end
%Initial resource values
R = S; % initial values of R1 and R2 equal the S1 and S2 values 
ResDyn = []; %The dynamics of the average resource values

%% Species parameters
%sp = 20; %Species number
d = Diff * ones(sp, 1); % diffusivity for each species
r = 1 * ones(sp, 1); %maximal growth rate
%r = 1 * linspace(5, 1, sp)'; %maximal growth rate
m = 0.25* ones(L, L, sp); %mortality of each species in each point

% Critical resource requirements R_eq(species#, resource#)
R_eq = [linspace(Params.TraitLow, Params.TraitHigh, sp)' linspace(Params.TraitHigh, Params.TraitLow, sp)'];  %Trade-off in resource requirements

%consumtion of resource j by rate species i. c(species#, resource#)
%optimal foraging theory --> origin to R_q values defines slope of consumption vectors 
c = [linspace(Params.TraitLow/Params.consump, Params.TraitHigh/Params.consump, sp)' linspace(Params.TraitHigh/Params.consump, Params.TraitLow/Params.consump, sp)'];



%Initial species number (x, y, species#)
%N = ones(L, L, sp); % initial values of N1 and N2 which are uniformly distributed  W

%Initial species number for randomly chosen set of species
N = 0.01 * rand(L,L,sp);
All_spec = 1:sp;
Exclude_spec = setdiff(All_spec, specID);
N(:,:,Exclude_spec) = 0;








